==> custom_pages-v1.12.8.zip: custom_pages/messages/fr/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Ajouter</strong> un élément {templateName}',
    '<strong>Custom</strong> Pages' => 'Pages <strong>personnalisées</strong>',
    '<strong>Edit</strong> snippet' => '<strong>Modifier</strong> l\'extrait',
    'Add' => 'Ajouter',
    'Add a file icon before the title' => 'Ajouter une icône avant l\'affichage du titre',
    'Additional IFrame Attributes' => 'Attributs supplémentaires de l’iFrame',
    'Adds plain HTML content to your site.' => 'Ajoute du contenu HTML simple à votre site.',
    'Advanced' => 'Avancé',
    'Allows the user to manage custom pages.' => 'Autoriser les utilisateurs à administrer les pages personnalisées',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Ce module permet d\'ajouter des pages personnalisées (Markdown, HTML, iframe ou liens) dans cet espace.',
    'Allows you to add content in MarkDown syntax.' => 'Vous permet d\'ajouter du contenu en utilisant la syntaxe Markdown.',
    'Alternate text' => 'Texte alternatif',
    'Always' => 'Toujours',
    'Always make a backup of your view files outside of your production environment!' => 'Toujours faire une sauvegarde de vos fichiers de type "view" en dehors de notre environnement de production !',
    'An empty allowed template selection will allow all container templates for this container.' => 'La sélection d\'un modèle autorisé vide permettra d\'utiliser tous les modèles de conteneurs pour ce conteneur.',
    'Authors' => 'Auteur·ices',
    'Back' => 'Retour',
    'Back to dashboard' => 'Retour à la vue d\'ensemble',
    'Back to overview' => 'Retour à la vue d\'ensemble',
    'Back to space' => 'Retour à l\'espace',
    'Can manage custom pages' => 'Peux administrer les pages personnalisées',
    'Cannot delete!' => 'Suppression impossible !',
    'Category' => 'Catégorie',
    'Configuration' => 'Configuration',
    'Container' => 'Conteneur',
    'Content' => 'Contenu',
    'Content filters' => 'Filtres de contenu',
    'Create' => 'Créer',
    'Css Class' => 'Classe CSS',
    'Custom' => 'Personnalisé',
    'Custom Pages' => 'Pages personnalisées',
    'Custom pages' => 'Pages personnalisées',
    'Dashboard' => 'Vue d\'ensemble',
    'Default' => 'Défaut',
    'Default Content' => 'Contenu par défaut',
    'Delete' => 'Supprimer',
    'Deleted.' => 'Supprimé.',
    'Edit' => 'Modifier',
    'Edit Page' => 'Modifier la page',
    'Empty' => 'Vide',
    'Empty content elements cannot be deleted!' => 'Les éléments vides ne peuvent être supprimés !',
    'Enter post content ID' => 'Saisir l’ID de contenu de la publication',
    'File' => 'Fichier',
    'Footer menu' => 'Menu du pied de page',
    'General' => 'Général',
    'Global Page' => 'Page globale',
    'Global Widget' => 'Widget global',
    'Go Back' => 'Retour',
    'Html' => 'HTML',
    'ID' => 'ID',
    'Icon' => 'Icône',
    'Iframe' => 'IFrame',
    'Import' => 'Importer',
    'Insert' => 'Insérer',
    'Invalid request data!' => 'Données de la requête invalides.',
    'Invalid template selection!' => 'Sélection du modèle invalide.',
    'Invalid type selection' => 'Sélection du type invalide',
    'Invalid view file selection!' => 'Sélection du fichier View invalide.',
    'Layout' => 'Mise en page',
    'Leave empty to list all records related to the current user.' => 'Laisser vide pour lister toutes les entrées liées à l’utilisateur ou utilisatrice actuel·le.',
    'Limit' => 'Limiter',
    'Link' => 'Lien',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => 'Gérer les mises en page, les mises en page de snippets et les conteneurs. Les mises en page définissent des structures de pages, les mises en page de snippets sont utilisées dans les barres latérales ou les sections, et les conteneurs sont des blocs de contenu réutilisables.',
    'MarkDown' => 'Markdown',
    'Menu settings' => 'Réglages du menu',
    'Navigation' => 'Navigation',
    'On this page you can configure general settings of your custom pages.' => 'Sur cette page vous pouvez configurer les paramètres généraux de vos pages personnalisées.',
    'Overview' => 'Vue d\'ensemble',
    'PHP' => 'PHP',
    'Page' => 'Page',
    'Page Content' => 'Contenu de page',
    'Pages' => 'Pages',
    'Panel' => 'Panneau',
    'People Buttons' => 'Boutons Membres',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'Veuillez choisir l’un des types de contenu suivants. Le type de contenu détermine la manière dont le contenu est intégré à votre site.',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Merci de garder à l\'esprit que les pages en php sont susceptibles de contenir des failles de sécurité, particulièrement quand elles manipulent des données saisies par l\'utilisateur. Pour plus d\'information, consultez la page  <a href="{url}">Meilleures pratiques sur la sécurité de Yii</a>.',
    'Public' => 'Public',
    'Reset' => 'Réinitialiser',
    'Reset the content to default value' => 'Réinitialiser le contenu au contenu par défaut',
    'Restrict to following comma separated content IDs' => 'Restreindre aux ID de contenu suivantes, séparées par des virgules',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'Cochez cette case uniquement pour les nœuds de texte. Décochez cette case si cet élément sert, par exemple, de valeur pour un attribut HTML.',
    'Settings' => 'Configuration',
    'Show additional file information (size)' => 'Afficher des informations supplémentaires du fichier (taille)',
    'Snippet' => 'Extrait',
    'Snippets' => 'Extraits',
    'Sort Order' => 'Ordre de tri',
    'Source' => 'Source',
    'Space' => 'Espace',
    'Space Members only' => 'Membres de l\'espace uniquement',
    'Space Navigation' => 'Menu espace',
    'Space Page' => 'Page d\'espace',
    'Space Widget' => 'Widget d’espace',
    'Spaces' => 'Espaces',
    'Stream' => 'Fil d\'actualités',
    'Stream options' => 'Options du fil d’actualités',
    'Style' => 'Style',
    'Style Class' => 'Classe de style',
    'Submit' => 'Envoyer',
    'Target Url' => 'URL cible',
    'Template' => 'Modèle',
    'Template Layout' => 'Disposition du modèle',
    'Templates' => 'Modèles',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Les modèles vous permettent de combiner des extraits avec une fonctionnalité d\'édition en ligne.',
    'This container does not allow any further items!' => 'Ce conteneur ne permet plus d\'ajouter d\'élément supplémentaire.',
    'Title' => 'Titre',
    'Top Navigation' => 'Menu de navigation',
    'Topics' => 'Sujets',
    'Type' => 'Type',
    'Upload image' => 'Transférer une image',
    'Usage' => 'Utilisation',
    'User Account Menu (Settings)' => 'Menu du compte utilisateur (paramètres)',
    'Visibility' => 'Visibilité',
    'Will embed the result of a given url as an iframe element.' => 'Va encapsuler le résultat d\'une url donnée dans un élément iframe.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Va rediriger la demande vers une url donnée (relative ou absolue).',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'Avec des pages en PHP vous pouvez créer des pages personnalisées au moyen de fichiers "view" dans votre système de fichiers. Merci de vérifier la configuration du module pour plus d\'information.',
    'Without adding to navigation (Direct link)' => 'Sans l\'ajouter au menu de navigation (lien direct)',
    'Wrap this HTML page with white panel' => 'Englober cette page HTML dans un panneau blanc',
    'You are not allowed to delete default content!' => 'Vous n\'êtes pas autorisé à supprimer le contenu par défaut.',
    'Administrative Users' => '',
    'Logged-In Users' => '',
    'Non-Logged-In Users' => '',
    'Resources' => '',
    'Start Page' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/fr/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Ajouter</strong> un élément {templateName}',
    '<strong>Custom</strong> Pages' => 'Pages <strong>personnalisées</strong>',
    '<strong>Edit</strong> snippet' => '<strong>Modifier</strong> l\'extrait',
    'Add' => 'Ajouter',
    'Add a file icon before the title' => 'Ajouter une icône avant l\'affichage du titre',
    'Additional IFrame Attributes' => 'Attributs supplémentaires de l’iFrame',
    'Adds plain HTML content to your site.' => 'Ajoute du contenu HTML simple à votre site.',
    'Advanced' => 'Avancé',
    'Allows the user to manage custom pages.' => 'Autoriser les utilisateurs à administrer les pages personnalisées',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Ce module permet d\'ajouter des pages personnalisées (Markdown, HTML, iframe ou liens) dans cet espace.',
    'Allows you to add content in MarkDown syntax.' => 'Vous permet d\'ajouter du contenu en utilisant la syntaxe Markdown.',
    'Alternate text' => 'Texte alternatif',
    'Always' => 'Toujours',
    'Always make a backup of your view files outside of your production environment!' => 'Toujours faire une sauvegarde de vos fichiers de type "view" en dehors de notre environnement de production !',
    'An empty allowed template selection will allow all container templates for this container.' => 'La sélection d\'un modèle autorisé vide permettra d\'utiliser tous les modèles de conteneurs pour ce conteneur.',
    'Authors' => 'Auteur·ices',
    'Back' => 'Retour',
    'Back to dashboard' => 'Retour à la vue d\'ensemble',
    'Back to overview' => 'Retour à la vue d\'ensemble',
    'Back to space' => 'Retour à l\'espace',
    'Can manage custom pages' => 'Peux administrer les pages personnalisées',
    'Cannot delete!' => 'Suppression impossible !',
    'Category' => 'Catégorie',
    'Configuration' => 'Configuration',
    'Container' => 'Conteneur',
    'Content' => 'Contenu',
    'Content filters' => 'Filtres de contenu',
    'Create' => 'Créer',
    'Css Class' => 'Classe CSS',
    'Custom' => 'Personnalisé',
    'Custom Pages' => 'Pages personnalisées',
    'Custom pages' => 'Pages personnalisées',
    'Dashboard' => 'Vue d\'ensemble',
    'Default' => 'Défaut',
    'Default Content' => 'Contenu par défaut',
    'Delete' => 'Supprimer',
    'Deleted.' => 'Supprimé.',
    'Edit' => 'Modifier',
    'Edit Page' => 'Modifier la page',
    'Empty' => 'Vide',
    'Empty content elements cannot be deleted!' => 'Les éléments vides ne peuvent être supprimés !',
    'Enter post content ID' => 'Saisir l’ID de contenu de la publication',
    'File' => 'Fichier',
    'Footer menu' => 'Menu du pied de page',
    'General' => 'Général',
    'Global Page' => 'Page globale',
    'Global Widget' => 'Widget global',
    'Go Back' => 'Retour',
    'Html' => 'HTML',
    'ID' => 'ID',
    'Icon' => 'Icône',
    'Iframe' => 'IFrame',
    'Import' => 'Importer',
    'Insert' => 'Insérer',
    'Invalid request data!' => 'Données de la requête invalides.',
    'Invalid template selection!' => 'Sélection du modèle invalide.',
    'Invalid type selection' => 'Sélection du type invalide',
    'Invalid view file selection!' => 'Sélection du fichier View invalide.',
    'Layout' => 'Mise en page',
    'Leave empty to list all records related to the current user.' => 'Laisser vide pour lister toutes les entrées liées à l’utilisateur ou utilisatrice actuel·le.',
    'Limit' => 'Limiter',
    'Link' => 'Lien',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => 'Gérer les mises en page, les mises en page de snippets et les conteneurs. Les mises en page définissent des structures de pages, les mises en page de snippets sont utilisées dans les barres latérales ou les sections, et les conteneurs sont des blocs de contenu réutilisables.',
    'MarkDown' => 'Markdown',
    'Menu settings' => 'Réglages du menu',
    'Navigation' => 'Navigation',
    'On this page you can configure general settings of your custom pages.' => 'Sur cette page vous pouvez configurer les paramètres généraux de vos pages personnalisées.',
    'Overview' => 'Vue d\'ensemble',
    'PHP' => 'PHP',
    'Page' => 'Page',
    'Page Content' => 'Contenu de page',
    'Pages' => 'Pages',
    'Panel' => 'Panneau',
    'People Buttons' => 'Boutons Membres',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'Veuillez choisir l’un des types de contenu suivants. Le type de contenu détermine la manière dont le contenu est intégré à votre site.',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Merci de garder à l\'esprit que les pages en php sont susceptibles de contenir des failles de sécurité, particulièrement quand elles manipulent des données saisies par l\'utilisateur. Pour plus d\'information, consultez la page  <a href="{url}">Meilleures pratiques sur la sécurité de Yii</a>.',
    'Public' => 'Public',
    'Reset' => 'Réinitialiser',
    'Reset the content to default value' => 'Réinitialiser le contenu au contenu par défaut',
    'Restrict to following comma separated content IDs' => 'Restreindre aux ID de contenu suivantes, séparées par des virgules',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'Cochez cette case uniquement pour les nœuds de texte. Décochez cette case si cet élément sert, par exemple, de valeur pour un attribut HTML.',
    'Settings' => 'Configuration',
    'Show additional file information (size)' => 'Afficher des informations supplémentaires du fichier (taille)',
    'Snippet' => 'Extrait',
    'Snippets' => 'Extraits',
    'Sort Order' => 'Ordre de tri',
    'Source' => 'Source',
    'Space' => 'Espace',
    'Space Members only' => 'Membres de l\'espace uniquement',
    'Space Navigation' => 'Menu espace',
    'Space Page' => 'Page d\'espace',
    'Space Widget' => 'Widget d’espace',
    'Spaces' => 'Espaces',
    'Stream' => 'Fil d\'actualités',
    'Stream options' => 'Options du fil d’actualités',
    'Style' => 'Style',
    'Style Class' => 'Classe de style',
    'Submit' => 'Envoyer',
    'Target Url' => 'URL cible',
    'Template' => 'Modèle',
    'Template Layout' => 'Disposition du modèle',
    'Templates' => 'Modèles',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Les modèles vous permettent de combiner des extraits avec une fonctionnalité d\'édition en ligne.',
    'This container does not allow any further items!' => 'Ce conteneur ne permet plus d\'ajouter d\'élément supplémentaire.',
    'Title' => 'Titre',
    'Top Navigation' => 'Menu de navigation',
    'Topics' => 'Sujets',
    'Type' => 'Type',
    'Upload image' => 'Transférer une image',
    'Usage' => 'Utilisation',
    'User Account Menu (Settings)' => 'Menu du compte utilisateur (paramètres)',
    'Visibility' => 'Visibilité',
    'Will embed the result of a given url as an iframe element.' => 'Va encapsuler le résultat d\'une url donnée dans un élément iframe.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Va rediriger la demande vers une url donnée (relative ou absolue).',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'Avec des pages en PHP vous pouvez créer des pages personnalisées au moyen de fichiers "view" dans votre système de fichiers. Merci de vérifier la configuration du module pour plus d\'information.',
    'Without adding to navigation (Direct link)' => 'Sans l\'ajouter au menu de navigation (lien direct)',
    'Wrap this HTML page with white panel' => 'Englober cette page HTML dans un panneau blanc',
    'You are not allowed to delete default content!' => 'Vous n\'êtes pas autorisé à supprimer le contenu par défaut.',
    'Activities' => '',
    'Activity' => '',
    'Activity content ID' => '',
    'Administrative Users' => '',
    'By creation date' => '',
    'By last update' => '',
    'Determine which Spaces should be taken into account.' => '',
    'Include all Spaces except selected' => '',
    'Include selected Spaces only' => '',
    'Logged-In Users' => '',
    'Non-Logged-In Users' => '',
    'Resources' => '',
    'Sorting' => '',
    'Space selection' => '',
    'Start Page' => '',
];
